@@ -19,7 +19,7 @@
 
 #include "kmoretools_p.h"
 #include "kmoretoolspresets_p.h"
-
+#include "knewstuff_debug.h"
 #include <QDebug>
 
 #include <KLocalizedString>
@@ -37,6 +37,7 @@ public:
     KMoreTools* kmt = nullptr;
 
     QMenu* menu = nullptr;
+    QWidget* parentWidget = nullptr;
 };
 
 class KMoreToolsLazyMenu : public QMenu
@@ -49,7 +50,7 @@ private Q_SLOTS:
     }
 
 public:
-    KMoreToolsLazyMenu(QWidget* parent = 0) : QMenu(parent) {
+    KMoreToolsLazyMenu(QWidget* parent = nullptr) : QMenu(parent) {
         connect(this, &QMenu::aboutToShow, this, &KMoreToolsLazyMenu::onAboutToShow);
     }
 
@@ -69,7 +70,7 @@ KMoreToolsMenuFactory::KMoreToolsMenuFactory(const QString& uniqueId)
 
 KMoreToolsMenuFactory::~KMoreToolsMenuFactory()
 {
-    if (d->menu) {
+    if (d->menu && !d->menu->parent()) {
         delete d->menu;
     }
 
@@ -97,7 +98,7 @@ static void addItemFromKmtService(KMoreToolsMenuBuilder* menuBuilder,
             // then the isInstalled was true because of the Exec line check
             // and we use the desktopfile provided by KMoreTools.
             // Otherwise *kService would crash.
-            qDebug() << "Desktop file not installed:" << kmtService->desktopEntryName() << "=> Use desktop file provided by KMoreTools";
+            qCDebug(KNEWSTUFF) << "Desktop file not installed:" << kmtService->desktopEntryName() << "=> Use desktop file provided by KMoreTools";
             kService = kmtService->kmtProvidedService();
         }
 
@@ -125,6 +126,8 @@ static void addItemsFromKmtServiceList(KMoreToolsMenuBuilder* menuBuilder,
                                       )
 {
     Q_FOREACH(auto kmtService, kmtServiceList) {
+        // Check the pointer just in case a null pointer got in somewhere
+        if (!kmtService) continue;
         if (kmtService->desktopEntryName() == firstMoreSectionDesktopEntryName) {
             // once we reach the potential first "more section desktop entry name"
             // all remaining services are added to the more section by default
@@ -232,6 +235,8 @@ static void addItemsForGroupingNameWithSpecialHandling(KMoreToolsMenuBuilder* me
         menuBuilder->setInitialItemTextTemplate(QStringLiteral("$Name")); // just use the application name
 
         Q_FOREACH(auto kmtService, kmtServiceList) {
+            // Check the pointer just in case a null pointer got in somewhere
+            if (!kmtService) continue;
             QUrl argUrl = url;
 
             if (url.isLocalFile()) { // this can only be done for local files, remote urls probably won't work for git clients anyway
@@ -269,7 +274,7 @@ QMenu* KMoreToolsMenuFactory::createMenuFromGroupingNames(
         delete d->menu;
     }
 
-    auto menu = new KMoreToolsLazyMenu();
+    auto menu = new KMoreToolsLazyMenu(d->parentWidget);
     menu->setAboutToShowAction([this, groupingNames, url](QMenu* m) { fillMenuFromGroupingNames(m, groupingNames, url); });
     d->menu = menu;
 
@@ -283,7 +288,7 @@ void KMoreToolsMenuFactory::fillMenuFromGroupingNames(QMenu* menu, const QString
 
     bool isMoreSection = false;
 
-    Q_FOREACH(auto groupingName, groupingNames) {
+    for (const auto &groupingName : groupingNames) {
 
         if (groupingName == QLatin1String("more:")) {
             isMoreSection = true;
@@ -305,3 +310,8 @@ void KMoreToolsMenuFactory::fillMenuFromGroupingNames(QMenu* menu, const QString
 
     menuBuilder->buildByAppendingToMenu(menu);
 }
+
+void KMoreToolsMenuFactory::setParentWidget(QWidget *widget)
+{
+    d->parentWidget = widget;
+}
